==> nextcloud-23.0.3.tgz: nextcloud/apps/circles/l10n/he.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "מעגלים",
    "Circles' files" : "קבצים של מעגלים",
    "Select circles to filter by" : "נא לבחור מעגלים לסינון",
    "No circles found" : "לא נמצאו מעגלים",
    "Please select circles to filter by" : "נא לבחור מעגלים לסינון",
    "No files found for the selected circles" : "לא נמצאו קבצים למעגלים הנבחרים",
    "You created the circle {circle}" : "יצרת את המעגל {circle}",
    "{author} created the circle {circle}" : "המעגל {circle} נוצר על ידי {author}",
    "You deleted {circle}" : "מחקת את {circle}",
    "{author} deleted {circle}" : "{circle} נמחק על ידי {author}",
    "You linked {group} to {circle}" : "קישרת את {group} אל {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} קושרה אל {circle} על ידי {author}",
    "You unlinked {group} from {circle}" : "ניתקת את {group} מהמעגל {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} נותקה מהמעגל {circle} על ידי {author}",
    "You sent a request to link {circle} with {remote}" : "שלחת בקשה לקשר את {circle} אל {remote}",
    "{author} sent a request to link {circle} with {remote}" : "נשלחה בקשה על ידי {author} לקשר את {circle} אל {remote}",
    "{remote} requested a link with {circle}" : "התקבלה בקשה לקישור מול {circle} על ידי {remote}",
    "The request to link {circle} with {remote} has been rejected" : "הבקשה לקשר את {circle} אל {remote} נדחתה",
    "The request to link {remote} with {circle} has been canceled remotely" : "הבקשה לקשר את {circle} אל {remote} בוטלה מהצד השני",
    "The request to link {circle} with {remote} has been accepted" : "הבקשה לקשר את {circle} אל {remote} התקבלה",
    "You canceled the request to link {circle} with {remote}" : "ביטלת את הבקשה לקשר את {circle} אל {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "הבקשה לקשר את {circle} אל {remote} בוטלה על ידי {author}",
    "You accepted the request to link {remote} with {circle}" : "נענית לבקשה לקשר את {remote} אל {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "הבקשה לקשר את {circle} אל {remote} נענתה על ידי {author}",
    "A link between {circle} and {remote} is now up and running" : "קישור בין {circle} לבין {remote} פעיל כעת",
    "The link between {circle} and {remote} has been shutdown remotely" : "הקישור בין {circle} לבין {remote} נכבה מרחוק",
    "You closed the link between {circle} and {remote}" : "סגרת את הקישור בין {circle} לבין {remote}",
    "{author} closed the link between {circle} and {remote}" : "הקישור בין {circle} לבין {remote} נסגר על ידי {author}",
    "You joined {circle}" : "הטרפת אל {circle}",
    "You accepted the invitation to join {circle}" : "קיבלת את הבקשה להצטרף אל {circle}",
    "{member} accepted the invitation to join {circle}" : "הבקשה להצטרף אל {circle} התקבלה על ידי {member}",
    "You added {member} as member to {circle}" : "הוספת את {member} לחברות במעגל {circle}",
    "You added {external} to {circle}" : "הוספת את {external} אל {circle}",
    "You accepted {member}'s request to join {circle}" : "נענית לבקשה של {member} להצטרף אל {circle}",
    "Your request to join {circle} has been accepted by {author}" : "בקשתך להצטרף אל {circle} נענתה על ידי {author}",
    "You left {circle}" : "עזבת את {circle}",
    "You declined the invitation to join {circle}" : "דחית את ההזמנה להצטרף אל {circle}",
    "You cancelled your request to join {circle}" : "ביטלת את בקשתך להצטרף אל {circle}",
    "You removed {member} from {circle}" : "הסרת את {member} מהמעגל {circle}",
    "You have been removed from {circle} by {author}" : "הוסרת מהמעגל {circle} על ידי {author}",
    "You removed {external} from {circle}" : "הסרת את {external} מהמעגל {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "ביטלת את ההזמנה של {member} להצטרף אל {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "הזמנתך להצטרף אל {circle} בוטלה על ידי {author}",
    "You invited {member} to join {circle}" : "הזמנת את {member} להצטרף אל {circle}",
    "You have been invited to join {circle} by {author}" : "הוזמנת להצטרף אל {circle} על ידי {author}",
    "You sent a request to join {circle}" : "שלחת בקשה להצטרף אל {circle}",
    "{member} sent a request to join {circle}" : "נשלחה בקשה על ידי {member} להצטרף אל {circle}",
    "You are the new owner of {circle}" : "קיבלת בעלות על {circle}",
    "{member} is the new owner of {circle}" : "הבעלות על {circle} הועברה לידי {member}",
    "Single" : "בודד",
    "Personal" : "אישי",
    "System" : "מערכת",
    "Visible" : "גלוי",
    "Open" : "פתוח",
    "Invite" : "הזמנה",
    "Join Request" : "בקשת הצטרפות",
    "Friends" : "חברים",
    "Password Protected" : "מוגן בססמה",
    "No Owner" : "אין בעלים",
    "Hidden" : "מוסתר",
    "Backend" : "מנגנון",
    "Local" : "מקומי",
    "Root" : "בסיס",
    "Circle Invite" : "הזמנה למעגל",
    "Mount point" : "נקודת עיגון",
    "Nextcloud User" : "משתמש Nextcloud",
    "Nextcloud Group" : "קבוצת Nextcloud",
    "Email Address" : "כתובת דוא״ל",
    "Contact" : "איש/אשת קשר",
    "Circle" : "מעגל",
    "Nextcloud App" : "יישומון Nextcloud",
    "Member" : "חבר",
    "Moderator" : "פיקוח",
    "Admin" : "מנהל",
    "Owner" : "בעלות",
    "Password to access »%s«" : "ססמת הגישה אל „%s”",
    "It is protected with the following password:" : "הוא מוגן בססמה הבאה:",
    "%1$s via %2$s" : "%1$s דרך %2$s",
    "Click the button below to open it." : "יש ללחוץ על הכפתור להלן כדי לפתוח אותו.",
    "Open »%s«" : "פתיחת „%s”",
    "Password to access files" : "ססמה לגשת לקבצים",
    "Initialisation Circles App" : "יישומון המעגלים נטען",
    "Fresh installation status" : "מצב ההתקנה החדשה",
    "Building Local Database" : "מסד הנתונים המקומי נבנה",
    "Testing Basic Circle Creation" : "נבדקת יצירת מעגל בסיסי",
    "Adding local users and moderators" : "הוספת משתמשים ומפקחים מקומיים",
    "Circle not found" : "המעגל לא נמצא",
    "Circle not found " : "המעגל לא נמצא",
    "A circle with that name exists" : "כבר קיים מעגל בשם הזה",
    "This member does not exist" : "חבר זה אינו קיים",
    "This user is already a member of the circle" : "משתמש זה כבר חבר במעגל",
    "This feature is not available for personal circles" : "תכונה זו אינה זמינה למעגלים אישיים",
    "You cannot join this circle" : "אין לך אפשרות להצטרף למעגל הזה",
    "Insufficient privileges" : "אין מספיק הרשאות",
    "This member is the owner of the circle" : "חבר זה הוא בעל המעגל",
    "You are already a member of this circle" : "כבר יש לך חברות במעגל זה",
    "You have been blocked from this circle" : "גישתך למעגל הזה נחסמה",
    "The user is already a member of this circle" : "המשתמש הוא כבר חבר במעגל הזה",
    "The user has already been invited into this circle" : "המשתמש הזה כבר הוזמן למעגל הזה",
    "You are now a member of the Circle \"%2$s\"" : "התקבלת לחברות במעגל „%2$s”",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "הוזמנת על ידי %1$s למעגל „%2$s”",
    "Accept" : "אשר",
    "Refuse" : "סירוב",
    "Leave the circle" : "לעזוב את המעגל",
    "Personal Circle" : "מעגל אישי",
    "You need a specify a type of circle" : "עליך לציין את סוג המעגל",
    "This member is not the owner of the circle" : "חבר זה אינו הבעלים של המעגל",
    "This member is not an admin of the circle" : "חבר זה אינו מנהל של המעגל",
    "Group contains too many members" : "הקבוצה מכילה יותר מדי חברים",
    "This group does not exist" : "קבוצה זו אינה קיימת",
    "This group is already linked to the circle" : "קבוצה זו כבר מקושרת למעגל זה",
    "now" : "עכשיו",
    "This user does not exist" : "המשתמש הזה לא קיים",
    "Email format is not valid" : "תצורת הדוא״ל שגויה",
    "This contact is not available" : "איש קשר זה אינו זמין",
    "This item is already shared with this circle" : "פריט זה כבר שותף עם המעגל הזה",
    "Could not find share" : "לא ניתן למצוא את השיתוף",
    "No files in here" : "אין כאן קבצים",
    "No entries found in this folder" : "לא נמצאו רשומות בתיקייה הזאת",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "מועד שינוי",
    "Are you sure you want to transfer your ownership?" : "להעביר את הבעלות שלך?",
    "This action is irreversible" : "זו פעולה בלתי הפיכה",
    "Personal circle" : "מעגל אישי",
    "Secret circle" : "מעגל סודי",
    "Closed circle" : "מעגל סגור",
    "Public circle" : "מעגל ציבורי",
    "Link Removed" : "הוסר קישור",
    "Link down" : "הקישור לא זמין",
    "Setting link" : "מוגדר קישור",
    "Request dismissed" : "הבקשה נדחתה",
    "Request sent" : "הבקשה נשלחה",
    "Link requested" : "התבקש קישור",
    "Link up" : "הקישור זמין",
    "Secret Circle" : "מעגל סודי",
    "Closed Circle" : "מעגל סגור",
    "Public Circle" : "מעגל ציבורי",
    "Secret" : "סוד",
    "Closed" : "סגור",
    "Public" : "ציבורי",
    "Not a member" : "לא חבר",
    "Unknown" : "לא ידוע",
    "Invited" : "הוזמן",
    "Requesting" : "בבקשה",
    "Blocked" : "נחסם",
    "Kicked" : "גורש",
    "This operation will add/invite all members of the group to the circle" : "פעולה זו תוסיף/תזמין את כל החברים של הקבוצה למעגל",
    "Please confirm" : "נא לאשר",
    "Are you sure you want to leave this circle?" : "לעזוב את המעגל הזה?",
    "Are you sure you want to delete this circle?" : "למחוק את המעגל הזה?",
    "Mail Address" : "כתובת דוא״ל",
    "Kick this member" : "סילוק החבר הזה",
    "Accept the request" : "קבלת הבקשה",
    "Dismiss the request" : "דחיית הבקשה",
    "Unlink this group" : "ביטול קישור הקבוצה הזו",
    "Remove this link" : "הסרת הקישור הזה",
    "Cancel the link request" : "ביטול בקשת הקישור",
    "Accept the link request" : "קבלת בקשת הקישור",
    "Reject the link request" : "דחיית בקשת הקישור",
    "Cannot join this circle" : "לא ניתן להצטרף למעגל הזה",
    "no error message" : "אין הודעת שגיאה",
    "You have joined this circle" : "הצטרפת למעגל",
    "You have requested to join this circle" : "ביקשת להצטרפת למעגל הזה",
    "You have left this circle" : "עזבת את המעגל",
    "Cannot leave this circle" : "לא ניתן לעזוב את המעגל",
    "You have deleted this circle" : "מחקת את המעגל",
    "Cannot delete this circle" : "לא ניתן למחוק את המעגל",
    "Issue while retrieving the details of this circle" : "תקלה בשליפת פרטי המעגל הזה",
    "Issue while retrieving the list of circles" : "תקלה בשליפת רשימת המעגלים",
    "Group '{name}' successfully added to the circle" : "הקבוצה ‚{name}’ נוספה למעגל בהצלחה",
    "Group '{name}' could not be added to the circle" : "לא ניתן להוסיף את הקבוצה ‚{name}’ למעגל",
    "Group '{name}' updated" : "הקבוצה ‚{name}’ עודכנה",
    "Group '{name}' could not be updated" : "לא ניתן היה לעדכן את הקבוצה ‚{name}’",
    "Group '{name}' successfully removed from the circle" : "הקבוצה ‚{name}’ הוסרה מהמעגל בהצלחה",
    "Group '{name}' could not be removed from the circle" : "לא ניתן להסיר את הקבוצה ‚{name}’ מהמעגל",
    "The status of the link could not be updated" : "לא ניתן לעדכן את מצב הקישור",
    "The status of the link has been updated" : "מצב הקישור עודכן",
    "Local User" : "משתמש מקומי",
    "Local Group" : "קבוצה מקומית",
    "A new member was added to the circle" : "חבר חדש נוסף למעגל",
    "Member could not be added to the circle" : "לא ניתן להוסיף את החבר למעגל",
    "The email address '{email}' was added to the circle" : "כתובת הדוא״ל ‚{email}’ נוספה למעגל",
    "The email address '{email}' could not be added to the circle" : "לא ניתן להוסיף את כתובת הדוא״ל ‚{email}’ למעגל",
    "A new contact was added to the circle" : "איש קשר חדש נוסף למעגל",
    "Issue while saving settings" : "תקלות בעת שמירת ההגדרות",
    "Settings saved." : "ההגדרות נשמרו.",
    "Shared to Circles" : "שותף למעגלים",
    "The name of your circle must contain at least 3 characters" : "שם המעגל שלך חייב להכיל לפחות 3 תווים",
    "Linked Groups are not allowed on this Nextcloud" : "אסור קבוצות מקושרות בעותק הזה של Nextcloud",
    "You cannot create this type of circle" : "אין לך אפשרות ליצור סוג כזה של מעגל",
    "You cannot display this type of circle" : "אין לך אפשרות להציג סוג כזה של מעגל",
    "Create a new circle" : "יצירת מעגל חדש",
    "Select a circle type" : "נא לבחור סוג מעגל",
    "Create a personal circle" : "יצירת מעגל אישי",
    "Create a public circle" : "יצירת מעגל ציבורי",
    "Create a closed circle" : "יצירת מעגל סגור",
    "Create a secret circle" : "יצירת מעגל סודי",
    "Creation" : "יצירה",
    "A personal circle is a list of users known only to the owner." : "מעגל אישי היא רשימה משתמשים שמוכרים רק לבעלים.",
    "This is the right option if you want to do recurrent sharing with the same list of local users." : "זאת האפשרות הנכונה אם חשוב לך לשתף באופן מחזורי את אותה רשימת משתמשים מקומיים.",
    "Personal circles" : "מעגלים אישיים",
    "Public circles" : "מעגלים ציבוריים",
    "Closed circles" : "מעגלים סגורים",
    "Secret circles" : "מעגלים סודיים",
    "All circles" : "כל המעגלים",
    "Search circles" : "חיפוש במעגלים",
    "No filter" : "אין מסנן",
    "Circles you belong to" : "מעגלים אליהם שויכת",
    "Circles you own" : "מעגלים בבעלותך",
    "No circle selected" : "לא נבחרו מעגלים",
    "Settings" : "הגדרות",
    "Pending invitation to join this circle" : "הזמנות ממתינות להצטרפות למעגל הזה",
    "You have a pending request to join this circle" : "יש לך בקשה ממתינה להצטרף למעגל הזה",
    "Add a member" : "הוספת חבר",
    "Link a group" : "קישור קבוצה",
    "Link a circle" : "קישור מעגל",
    "Join this circle" : "הצטרפות למעגל הזה",
    "Delete circle" : "מחיקת מעגל",
    "Edit circle" : "עריכת מעגל",
    "Accept the invitation" : "קבלת ההזמנה",
    "Decline the invitation" : "דחיית ההזמנה",
    "Leave this circle" : "לעזוב את המעגל הזה",
    "Link to a circle" : "קישור למעגל",
    "Return to menu" : "חזרה לתפריט",
    "Username" : "שם משתמש",
    "Level" : "רמה",
    "Status" : "מצב",
    "Group Name" : "שם הקבוצה",
    "Link" : "קישור",
    "Linked" : "מקושרת",
    "Name of the Circle" : "שם המעגל",
    "Description" : "תיאור",
    "Members limit" : "מגבלת חברים",
    "Password enforcement" : "אכיפת ססמה",
    "External share will be protected by a randomly generated password" : "שיתופים חיצוניים ימוגנו בססמה אקראית",
    "Single password" : "ססמה אחידה",
    "Change password" : "החלפת ססמה",
    "Save settings" : "הגדרות שמירה",
    "Maximum number of members per circle" : "מספר החברים המרבי למעגל",
    "Allow linking of groups" : "לאפשר קישור קבוצות",
    "Groups can be linked to circles." : "אפשר לקשר קבוצות למעגלים."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-23.0.9.tgz: nextcloud/apps/circles/l10n/he.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "מעגלים",
    "Circles' files" : "קבצים של מעגלים",
    "Select circles to filter by" : "נא לבחור מעגלים לסינון",
    "No circles found" : "לא נמצאו מעגלים",
    "Please select circles to filter by" : "נא לבחור מעגלים לסינון",
    "No files found for the selected circles" : "לא נמצאו קבצים למעגלים הנבחרים",
    "You created the circle {circle}" : "יצרת את המעגל {circle}",
    "{author} created the circle {circle}" : "המעגל {circle} נוצר על ידי {author}",
    "You deleted {circle}" : "מחקת את {circle}",
    "{author} deleted {circle}" : "{circle} נמחק על ידי {author}",
    "You linked {group} to {circle}" : "קישרת את {group} אל {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} קושרה אל {circle} על ידי {author}",
    "You unlinked {group} from {circle}" : "ניתקת את {group} מהמעגל {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} נותקה מהמעגל {circle} על ידי {author}",
    "You sent a request to link {circle} with {remote}" : "שלחת בקשה לקשר את {circle} אל {remote}",
    "{author} sent a request to link {circle} with {remote}" : "נשלחה בקשה על ידי {author} לקשר את {circle} אל {remote}",
    "{remote} requested a link with {circle}" : "התקבלה בקשה לקישור מול {circle} על ידי {remote}",
    "The request to link {circle} with {remote} has been rejected" : "הבקשה לקשר את {circle} אל {remote} נדחתה",
    "The request to link {remote} with {circle} has been canceled remotely" : "הבקשה לקשר את {circle} אל {remote} בוטלה מהצד השני",
    "The request to link {circle} with {remote} has been accepted" : "הבקשה לקשר את {circle} אל {remote} התקבלה",
    "You canceled the request to link {circle} with {remote}" : "ביטלת את הבקשה לקשר את {circle} אל {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "הבקשה לקשר את {circle} אל {remote} בוטלה על ידי {author}",
    "You accepted the request to link {remote} with {circle}" : "נענית לבקשה לקשר את {remote} אל {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "הבקשה לקשר את {circle} אל {remote} נענתה על ידי {author}",
    "A link between {circle} and {remote} is now up and running" : "קישור בין {circle} לבין {remote} פעיל כעת",
    "The link between {circle} and {remote} has been shutdown remotely" : "הקישור בין {circle} לבין {remote} נכבה מרחוק",
    "You closed the link between {circle} and {remote}" : "סגרת את הקישור בין {circle} לבין {remote}",
    "{author} closed the link between {circle} and {remote}" : "הקישור בין {circle} לבין {remote} נסגר על ידי {author}",
    "You joined {circle}" : "הטרפת אל {circle}",
    "You accepted the invitation to join {circle}" : "קיבלת את הבקשה להצטרף אל {circle}",
    "{member} accepted the invitation to join {circle}" : "הבקשה להצטרף אל {circle} התקבלה על ידי {member}",
    "You added {member} as member to {circle}" : "הוספת את {member} לחברות במעגל {circle}",
    "You added {external} to {circle}" : "הוספת את {external} אל {circle}",
    "You accepted {member}'s request to join {circle}" : "נענית לבקשה של {member} להצטרף אל {circle}",
    "Your request to join {circle} has been accepted by {author}" : "בקשתך להצטרף אל {circle} נענתה על ידי {author}",
    "You left {circle}" : "עזבת את {circle}",
    "You declined the invitation to join {circle}" : "דחית את ההזמנה להצטרף אל {circle}",
    "You cancelled your request to join {circle}" : "ביטלת את בקשתך להצטרף אל {circle}",
    "You removed {member} from {circle}" : "הסרת את {member} מהמעגל {circle}",
    "You have been removed from {circle} by {author}" : "הוסרת מהמעגל {circle} על ידי {author}",
    "You removed {external} from {circle}" : "הסרת את {external} מהמעגל {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "ביטלת את ההזמנה של {member} להצטרף אל {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "הזמנתך להצטרף אל {circle} בוטלה על ידי {author}",
    "You invited {member} to join {circle}" : "הזמנת את {member} להצטרף אל {circle}",
    "You have been invited to join {circle} by {author}" : "הוזמנת להצטרף אל {circle} על ידי {author}",
    "You sent a request to join {circle}" : "שלחת בקשה להצטרף אל {circle}",
    "{member} sent a request to join {circle}" : "נשלחה בקשה על ידי {member} להצטרף אל {circle}",
    "You are the new owner of {circle}" : "קיבלת בעלות על {circle}",
    "{member} is the new owner of {circle}" : "הבעלות על {circle} הועברה לידי {member}",
    "Single" : "בודד",
    "Personal" : "אישי",
    "System" : "מערכת",
    "Visible" : "גלוי",
    "Open" : "פתוח",
    "Invite" : "הזמנה",
    "Join Request" : "בקשת הצטרפות",
    "Friends" : "חברים",
    "Password Protected" : "מוגן בססמה",
    "No Owner" : "אין בעלים",
    "Hidden" : "מוסתר",
    "Backend" : "מנגנון",
    "Local" : "מקומי",
    "Root" : "בסיס",
    "Circle Invite" : "הזמנה למעגל",
    "Federated" : "Federated",
    "Mount point" : "נקודת עיגון",
    "Nextcloud User" : "משתמש Nextcloud",
    "Nextcloud Group" : "קבוצת Nextcloud",
    "Email Address" : "כתובת דוא״ל",
    "Contact" : "איש/אשת קשר",
    "Circle" : "מעגל",
    "Nextcloud App" : "יישומון Nextcloud",
    "Member" : "חבר",
    "Moderator" : "פיקוח",
    "Admin" : "מנהל",
    "Owner" : "בעלות",
    "Password to access »%1$s« shared to you by %2$s" : "סיסמא לגישה ל-»%1$s« משותף לך על ידי %2$s",
    "Password to access »%s«" : "ססמת הגישה אל „%s”",
    "It is protected with the following password:" : "הוא מוגן בססמה הבאה:",
    "%1$s via %2$s" : "%1$s דרך %2$s",
    "Click the button below to open it." : "יש ללחוץ על הכפתור להלן כדי לפתוח אותו.",
    "Open »%s«" : "פתיחת „%s”",
    "Password to access files" : "ססמה לגשת לקבצים",
    "Initialisation Circles App" : "יישומון המעגלים נטען",
    "Fresh installation status" : "מצב ההתקנה החדשה",
    "Building Local Database" : "מסד הנתונים המקומי נבנה",
    "Testing Basic Circle Creation" : "נבדקת יצירת מעגל בסיסי",
    "Adding local users and moderators" : "הוספת משתמשים ומפקחים מקומיים",
    "Circle not found" : "המעגל לא נמצא",
    "Circle not found " : "המעגל לא נמצא",
    "A circle with that name exists" : "כבר קיים מעגל בשם הזה",
    "This member does not exist" : "חבר זה אינו קיים",
    "This user is already a member of the circle" : "משתמש זה כבר חבר במעגל",
    "This feature is not available for personal circles" : "תכונה זו אינה זמינה למעגלים אישיים",
    "You cannot join this circle" : "אין לך אפשרות להצטרף למעגל הזה",
    "Insufficient privileges" : "אין מספיק הרשאות",
    "This member is the owner of the circle" : "חבר זה הוא בעל המעגל",
    "You are already a member of this circle" : "כבר יש לך חברות במעגל זה",
    "You have been blocked from this circle" : "גישתך למעגל הזה נחסמה",
    "The user is already a member of this circle" : "המשתמש הוא כבר חבר במעגל הזה",
    "The user has already been invited into this circle" : "המשתמש הזה כבר הוזמן למעגל הזה",
    "You are now a member of the Circle \"%2$s\"" : "התקבלת לחברות במעגל „%2$s”",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "הוזמנת על ידי %1$s למעגל „%2$s”",
    "Accept" : "אשר",
    "Refuse" : "סירוב",
    "Leave the circle" : "לעזוב את המעגל",
    "%s" : "%s",
    "Personal Circle" : "מעגל אישי",
    "You need a specify a type of circle" : "עליך לציין את סוג המעגל",
    "This member is not the owner of the circle" : "חבר זה אינו הבעלים של המעגל",
    "This member is not an admin of the circle" : "חבר זה אינו מנהל של המעגל",
    "Group contains too many members" : "הקבוצה מכילה יותר מדי חברים",
    "This group does not exist" : "קבוצה זו אינה קיימת",
    "This group is already linked to the circle" : "קבוצה זו כבר מקושרת למעגל זה",
    "now" : "עכשיו",
    "This user does not exist" : "המשתמש הזה לא קיים",
    "Email format is not valid" : "תצורת הדוא״ל שגויה",
    "This contact is not available" : "איש קשר זה אינו זמין",
    "This item is already shared with this circle" : "פריט זה כבר שותף עם המעגל הזה",
    "Could not find share" : "לא ניתן למצוא את השיתוף",
    "No files in here" : "אין כאן קבצים",
    "No entries found in this folder" : "לא נמצאו רשומות בתיקייה הזאת",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "מועד שינוי"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
